==> 1.1.0.tar.gz: glance-wx/wepy.config.js <==
const path = require('path')
var prod = process.env.NODE_ENV === 'production'

module.exports = {
    wpyExt: '.wpy',
    build: {
        web: {
            htmlTemplate: path.join('src', 'index.template.html'),
            htmlOutput: path.join('web', 'index.html'),
            jsOutput: path.join('web', 'index.js')
        }
    },
    resolve: {
        alias: {
			lib: path.join(__dirname, 'src/lib/lib'),
            '@': path.join(__dirname, 'src')
        },
        modules: ['node_modules']
    },
    // eslint: true,
    compilers: {
        // less: {
        //   compress: true
        // },
        sass: {
            outputStyle: 'compressed'
        },
        babel: {
            sourceMap: true,
            presets: [
                'env'
            ],
            plugins: [
                'transform-class-properties',
                'transform-decorators-legacy',
                'transform-object-rest-spread',
                'transform-export-extensions'
            ]
        }
    },
    plugins: {
		'img2base64': {
			css: false,
			html: true,
			fileType: 'scss',
			path: '/src/img'
		}
	},
    appConfig: {
        noPromiseAPI: ['createSelectorQuery']
    }
}

if (prod) {
    delete module.exports.compilers.babel.sourcesMap
    // 压缩sass
    module.exports.compilers['sass'] = {
        outputStyle: 'compressed'
    }

    // 压缩less
    // module.exports.compilers['less'] = {
    //   compress: true
    // }

    // 压缩js
    module.exports.plugins = {
        uglifyjs: {
            filter: /\.js$/,
            config: {}
        },
        imagemin: {
            filter: /\.(jpg|png|jpeg)$/,
            config: {
                jpg: {
                    quality: 80
                },
                png: {
                    quality: 80
                }
            }
		},
		img2base64: {
			css: false,
			html: true,
			fileType: 'scss',
			path: '/src/img'
		}
    }
}

==> 1.1.3.tar.gz: glance-wx/wepy.config.js <==
const path = require('path')
var prod = process.env.NODE_ENV === 'production'

module.exports = {
    wpyExt: '.wpy',
    build: {
        web: {
            htmlTemplate: path.join('src', 'index.template.html'),
            htmlOutput: path.join('web', 'index.html'),
            jsOutput: path.join('web', 'index.js')
        }
    },
    resolve: {
        alias: {
			'ald': path.join(__dirname, 'src/utils/ald-stat'),
			'lib': path.join(__dirname, 'src/lib/lib'),
            '@': path.join(__dirname, 'src')
        },
        modules: ['node_modules']
    },
    // eslint: true,
    compilers: {
        // less: {
        //   compress: true
        // },
        sass: {
            outputStyle: 'compressed'
        },
        babel: {
            sourceMap: true,
            presets: [
                'env'
            ],
            plugins: [
                'transform-class-properties',
                'transform-decorators-legacy',
                'transform-object-rest-spread',
                'transform-export-extensions'
            ]
        }
    },
    plugins: {
		'img2base64': {
			css: false,
			html: true,
			fileType: 'scss',
			path: '/src/img'
		}
	},
    appConfig: {
        noPromiseAPI: ['createSelectorQuery']
    }
}

if (prod) {
    delete module.exports.compilers.babel.sourcesMap
    // 压缩sass
    module.exports.compilers['sass'] = {
        outputStyle: 'compressed'
    }

    // 压缩less
    // module.exports.compilers['less'] = {
    //   compress: true
    // }

    // 压缩js
    module.exports.plugins = {
        uglifyjs: {
            filter: /\.js$/,
            config: {}
        },
        imagemin: {
            filter: /\.(jpg|png|jpeg)$/,
            config: {
                jpg: {
                    quality: 80
                },
                png: {
                    quality: 80
                }
            }
		},
		img2base64: {
			css: false,
			html: true,
			fileType: 'scss',
			path: '/src/img'
		}
    }
}
